@@ -91,8 +91,8 @@ void DavCollectionsFetchJobPrivate::principalFetchFinished(KJob *job)
     const DavPrincipalHomeSetsFetchJob *davJob = qobject_cast<DavPrincipalHomeSetsFetchJob *>(job);
 
     if (davJob->error()) {
-        if (davJob->latestResponseCode()) {
-            // If we have a HTTP response code then this may mean that
+        if (davJob->canRetryLater()) {
+            // If we have a non-persistent HTTP error code then this may mean that
             // the URL was not a principal URL. Retry as if it were a calendar URL.
             qCDebug(KDAV_LOG) << job->errorText();
             doCollectionsFetch(mUrl.url());
@@ -165,7 +165,7 @@ void DavCollectionsFetchJobPrivate::collectionsFetchFinished(KJob *job)
 
         // Validate that we got a valid PROPFIND response
         QDomDocument response;
-        response.setContent(davJob->responseData(), true);
+        response.setContent(davJob->responseData(), QDomDocument::ParseOption::UseNamespaceProcessing);
         QDomElement rootElement = response.documentElement();
         if (rootElement.tagName().compare(QLatin1String("multistatus"), Qt::CaseInsensitive) != 0) {
             setError(ERR_COLLECTIONFETCH);
@@ -176,7 +176,7 @@ void DavCollectionsFetchJobPrivate::collectionsFetchFinished(KJob *job)
 
         QByteArray resp = davJob->responseData();
         QDomDocument document;
-        if (!document.setContent(resp, true)) {
+        if (!document.setContent(resp, QDomDocument::ParseOption::UseNamespaceProcessing)) {
             setError(ERR_COLLECTIONFETCH);
             setErrorTextFromDavError();
             subjobFinished();
